/*
**	This file is part of XDowl
**	Copyright (c) 1994 Jamie Mazer
**	California Institute of Technology
**	<mazer@asterix.cns.caltech.edu>
*/

/******************************************************************
**  RCSID: $Id: getfile.h,v 2.44 2002/07/15 04:30:08 cmalek Exp $
** Program: dowl
**  Module: getfile.h
**  Author: mazer
** Descrip: interface file for getfile.c
**
** Revision History (most recent last)
**
*******************************************************************/

#define GF_INDEF	0
#define GF_ONCE		1

#define GF_NODIRS	0
#define GF_DIRS		1

#define GF_ALLFILES	NULL

struct noblock_data {
	Widget pshell;
	void (*cbfn) ();
	caddr_t cbdata;
	int once;
};

extern char *fileBoxMatch(char *, char *, char *, char *, int);
extern char *fileBox(char *, char *, char *);

extern void fileBoxMatch_noblock(char *, char *, char *, char *, int,
				 void (*)(), caddr_t, int);
